@@ -6,6 +6,5 @@ __MOMONGA__ = b"NTh3Yw=="
 __LIGHT__ = b"|OW5hMQ=="
 __SEPHIROTH__ = b"ZzRlbA=="
 ANIME = b"|".join([__SEPHIROTH__, __MOMONGA__, __ZERO__, __LIGHT__])
-PREFER_PARTIAL = True
 
-__all__ = ("ANIME", "PREFER_PARTIAL")
+__all__ = ("ANIME",)
