@@ -1,12 +1,12 @@
 from __future__ import annotations
 
-import asyncio
 import contextlib
 import socket
-import typing
 
 import aiohttp
+from yarl import URL
 
+from pylav.compat import json
 from pylav.exceptions.base import PyLavException
 from pylav.logging import getLogger
 
@@ -30,52 +30,27 @@ async def fetch_servers() -> set[str]:
     """
     Get IP of all currently available `Radio Browser` servers.
     Returns:
-        set: List of IPs
+        set: List of addresses.
     """
-    ips = set()
     try:
-        data = await asyncio.to_thread(socket.getaddrinfo, "all.api.radio-browser.info", 80, 0, 0, socket.IPPROTO_TCP)
+        async with aiohttp.ClientSession(json_serialize=json.dumps) as session:
+            async with session.get("http://all.api.radio-browser.info/json/servers") as response:
+                data = await response.json(loads=json.loads)
     except socket.gaierror:
         return set()
     else:
-        ips.update({i[4][0] for i in data})
-    return typing.cast(set[str], ips)
+        return {server["name"] for server in data}
 
 
-async def rdns_lookup(ip: str) -> str:
-    """
-    Reverse DNS lookup.
-    Returns:
-        str: hostname
-    """
-
-    try:
-        hostname, _, _ = await asyncio.to_thread(socket.gethostbyaddr, ip)
-    except socket.herror as exc:
-        raise RDNSLookupError(ip) from exc
-    return hostname
-
-
-async def fetch_hosts() -> list[str]:
-    names = []
+async def pick_base_url(session: aiohttp.ClientSession) -> URL | None:
     servers = await fetch_servers()
-
-    for ip in servers:
-        try:
-            host_name = await rdns_lookup(ip)
-        except RDNSLookupError as exc:
-            LOGGER.trace(exc.error_msg, exc_info=True)
-        else:
-            names.append(host_name)
-    return names
-
-
-async def pick_base_url(session: aiohttp.ClientSession) -> str | None:
-    hosts = await fetch_hosts()
-    for host in hosts:
+    if not servers:
+        LOGGER.warning("RadioBrowser API seems to be down at the moment, disabling Radio functionality.")
+        return None
+    for host in servers:
         with contextlib.suppress(Exception):
             async with session.get(f"https://{host}/json/stats") as response:
                 if response.status == 200:
-                    return f"https://{host}"
+                    return URL(f"https://{host}")
                 LOGGER.verbose("Error interacting with %s: %s", host, response.status)
-    LOGGER.error("All the following hosts for the RadioBrowser API are broken: %s", ", ".join(hosts))
+    LOGGER.error("All the following hosts for the RadioBrowser API are broken: %s", ", ".join(servers))
