@@ -5,7 +5,7 @@ import dataclasses
 
 @dataclasses.dataclass(repr=True, frozen=True, kw_only=True, slots=True)
 class State:
-    time: int = 0
-    connected: bool = False
-    ping: int = -1
+    time: int
+    connected: bool
+    ping: int
     position: int | None = 0
