@@ -3,7 +3,7 @@ from __future__ import annotations
 from piccolo.columns import JSONB, BigInt, Boolean, Text, Timestamptz
 from piccolo.table import Table
 
-from pylav.constants.config import CONFIG_DIR, USE_BUNDLED_EXTERNAL_PYLAV_NODE
+from pylav.constants.config import CONFIG_DIR, LOCAL_TRACKS_FOLDER, USE_BUNDLED_EXTERNAL_PYLAV_NODE
 from pylav.storage.database.tables.misc import DATABASE_ENGINE
 
 
@@ -14,7 +14,7 @@ class LibConfigRow(Table, db=DATABASE_ENGINE, tablename="lib_config"):
     java_path = Text(null=False, default="java")
     enable_managed_node = Boolean(null=False, default=True)
     auto_update_managed_nodes = Boolean(null=False, default=True)
-    localtrack_folder = Text(null=True, default=str(CONFIG_DIR / "music"))
+    localtrack_folder = Text(null=True, default=str(LOCAL_TRACKS_FOLDER or (CONFIG_DIR / "music")))
     download_id = BigInt(index=True, default=0)
     update_bot_activity = Boolean(null=False, default=False)
     use_bundled_pylav_external = Boolean(null=False, default=USE_BUNDLED_EXTERNAL_PYLAV_NODE)
